pub enum EdgeEvent {
Rebirthed,
RebirthDebounced,
NodeCommand(Payload),
DeviceCommand {
device: String,
payload: Payload,
},
PrimaryHostState(StatePayload),
Ignored,
}Expand description
An event surfaced by EdgeNode::handle_incoming.
Variants
Rebirthed
A rebirth was requested and the birth sequence was re-published.
RebirthDebounced
A rebirth was requested but suppressed by the debounce window.
NodeCommand(Payload)
An Edge Node command (NCMD) other than a rebirth.
DeviceCommand
A Device command (DCMD).
PrimaryHostState(StatePayload)
A primary-host STATE update.
Ignored
A message that did not require engine action.